@@ -112,11 +112,13 @@ nautilus_link_local_create (const char *directory_uri,
 			    const char *image,
 			    const char *target_uri,
 			    const GdkPoint *point,
+			    int screen,
 			    NautilusLinkType type)
 {
 	return nautilus_link_desktop_file_local_create (directory_uri,
 							name, image,
-							target_uri, point,
+							target_uri, 
+							point, screen,
 							type);
 }
 
@@ -125,7 +127,6 @@ nautilus_link_local_set_icon (const char *uri, const char *icon_name)
 {
 	gboolean result;
 	NautilusFile *file;
-	GList *attributes;
 
 	switch (get_link_style_for_local_file (uri, NULL)) {
 	case desktop:
@@ -139,10 +140,8 @@ nautilus_link_local_set_icon (const char *uri, const char *icon_name)
 	}
 
 	file = nautilus_file_get (uri);
-	attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_ACTIVATION_URI);
-	nautilus_file_invalidate_attributes (file, attributes);
+	nautilus_file_invalidate_attributes (file, NAUTILUS_FILE_ATTRIBUTE_ACTIVATION_URI);
 	nautilus_file_unref (file);
-	g_list_free (attributes);
 
 	return result;
 }
@@ -152,7 +151,6 @@ nautilus_link_local_set_link_uri (const char *uri, const char *link_uri)
 {
 	gboolean result;
 	NautilusFile *file;
-	GList *attributes;
 
 	switch (get_link_style_for_local_file (uri, NULL)) {
 	case desktop:
@@ -168,10 +166,8 @@ nautilus_link_local_set_link_uri (const char *uri, const char *link_uri)
 
 	
 	file = nautilus_file_get (uri);
-	attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_ACTIVATION_URI);
-	nautilus_file_invalidate_attributes (file, attributes);
+	nautilus_file_invalidate_attributes (file, NAUTILUS_FILE_ATTRIBUTE_ACTIVATION_URI);
 	nautilus_file_unref (file);
-	g_list_free (attributes);
 
 	return result;
 }
@@ -233,6 +229,19 @@ nautilus_link_local_get_link_type (const char *uri, GnomeVFSFileInfo *info)
 	}
 }
 
+gboolean
+nautilus_link_local_is_utf8 (const char *uri,
+			     GnomeVFSFileInfo *info)
+{
+	switch (get_link_style_for_local_file (uri, info)) {
+	case desktop:
+		return nautilus_link_desktop_file_local_is_utf8 (uri);
+	case historical:
+	default:
+		return FALSE;
+	}
+}
+
 char *
 nautilus_link_get_link_uri_given_file_contents (const char *uri,
 						const char *file_contents,
@@ -317,7 +326,8 @@ nautilus_link_local_is_special_link (const char *uri)
 void
 nautilus_link_local_create_from_gnome_entry (GnomeDesktopItem *item,
 					     const char *dest_uri,
-					     const GdkPoint *position)
+					     const GdkPoint *position,
+					     int screen)
 {
-	nautilus_link_desktop_file_local_create_from_gnome_entry (item, dest_uri, position);
+	nautilus_link_desktop_file_local_create_from_gnome_entry (item, dest_uri, position, screen);
 }
